from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from aliro_quantum_networking.api.authentication_api import AuthenticationApi
from aliro_quantum_networking.api.submissions_api import SubmissionsApi
from aliro_quantum_networking.api.user_api import UserApi
from aliro_quantum_networking.api.utils_api import UtilsApi



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class QuantumConnection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attenuation': 'float',
        'dark_count_rate': 'float',
        'distance': 'float',
        'efficiency': 'float',
        'error_models': 'list[ErrorModel]',
        'name': 'str',
        'node_from': 'str',
        'node_to': 'str'
    }

    attribute_map = {
        'attenuation': 'attenuation',
        'dark_count_rate': 'darkCountRate',
        'distance': 'distance',
        'efficiency': 'efficiency',
        'error_models': 'errorModels',
        'name': 'name',
        'node_from': 'nodeFrom',
        'node_to': 'nodeTo'
    }

    def __init__(self, attenuation=0.001, dark_count_rate=None, distance=1000, efficiency=1, error_models=None, name=None, node_from=None, node_to=None, local_vars_configuration=None):  # noqa: E501
        """QuantumConnection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attenuation = None
        self._dark_count_rate = None
        self._distance = None
        self._efficiency = None
        self._error_models = None
        self._name = None
        self._node_from = None
        self._node_to = None
        self.discriminator = None

        if attenuation is not None:
            self.attenuation = attenuation
        if dark_count_rate is not None:
            self.dark_count_rate = dark_count_rate
        if distance is not None:
            self.distance = distance
        if efficiency is not None:
            self.efficiency = efficiency
        if error_models is not None:
            self.error_models = error_models
        if name is not None:
            self.name = name
        self.node_from = node_from
        self.node_to = node_to

    @property
    def attenuation(self):
        """Gets the attenuation of this QuantumConnection.  # noqa: E501


        :return: The attenuation of this QuantumConnection.  # noqa: E501
        :rtype: float
        """
        return self._attenuation

    @attenuation.setter
    def attenuation(self, attenuation):
        """Sets the attenuation of this QuantumConnection.


        :param attenuation: The attenuation of this QuantumConnection.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                attenuation is not None and attenuation < 0):  # noqa: E501
            raise ValueError("Invalid value for `attenuation`, must be a value greater than or equal to `0`")  # noqa: E501

        self._attenuation = attenuation

    @property
    def dark_count_rate(self):
        """Gets the dark_count_rate of this QuantumConnection.  # noqa: E501


        :return: The dark_count_rate of this QuantumConnection.  # noqa: E501
        :rtype: float
        """
        return self._dark_count_rate

    @dark_count_rate.setter
    def dark_count_rate(self, dark_count_rate):
        """Sets the dark_count_rate of this QuantumConnection.


        :param dark_count_rate: The dark_count_rate of this QuantumConnection.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                dark_count_rate is not None and dark_count_rate < 0):  # noqa: E501
            raise ValueError("Invalid value for `dark_count_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._dark_count_rate = dark_count_rate

    @property
    def distance(self):
        """Gets the distance of this QuantumConnection.  # noqa: E501

        The distance in meters  # noqa: E501

        :return: The distance of this QuantumConnection.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this QuantumConnection.

        The distance in meters  # noqa: E501

        :param distance: The distance of this QuantumConnection.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                distance is not None and distance < 0):  # noqa: E501
            raise ValueError("Invalid value for `distance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._distance = distance

    @property
    def efficiency(self):
        """Gets the efficiency of this QuantumConnection.  # noqa: E501


        :return: The efficiency of this QuantumConnection.  # noqa: E501
        :rtype: float
        """
        return self._efficiency

    @efficiency.setter
    def efficiency(self, efficiency):
        """Sets the efficiency of this QuantumConnection.


        :param efficiency: The efficiency of this QuantumConnection.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                efficiency is not None and efficiency > 1):  # noqa: E501
            raise ValueError("Invalid value for `efficiency`, must be a value less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                efficiency is not None and efficiency < 0):  # noqa: E501
            raise ValueError("Invalid value for `efficiency`, must be a value greater than or equal to `0`")  # noqa: E501

        self._efficiency = efficiency

    @property
    def error_models(self):
        """Gets the error_models of this QuantumConnection.  # noqa: E501


        :return: The error_models of this QuantumConnection.  # noqa: E501
        :rtype: list[ErrorModel]
        """
        return self._error_models

    @error_models.setter
    def error_models(self, error_models):
        """Sets the error_models of this QuantumConnection.


        :param error_models: The error_models of this QuantumConnection.  # noqa: E501
        :type: list[ErrorModel]
        """

        self._error_models = error_models

    @property
    def name(self):
        """Gets the name of this QuantumConnection.  # noqa: E501


        :return: The name of this QuantumConnection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this QuantumConnection.


        :param name: The name of this QuantumConnection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def node_from(self):
        """Gets the node_from of this QuantumConnection.  # noqa: E501


        :return: The node_from of this QuantumConnection.  # noqa: E501
        :rtype: str
        """
        return self._node_from

    @node_from.setter
    def node_from(self, node_from):
        """Sets the node_from of this QuantumConnection.


        :param node_from: The node_from of this QuantumConnection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and node_from is None:  # noqa: E501
            raise ValueError("Invalid value for `node_from`, must not be `None`")  # noqa: E501

        self._node_from = node_from

    @property
    def node_to(self):
        """Gets the node_to of this QuantumConnection.  # noqa: E501


        :return: The node_to of this QuantumConnection.  # noqa: E501
        :rtype: str
        """
        return self._node_to

    @node_to.setter
    def node_to(self, node_to):
        """Sets the node_to of this QuantumConnection.


        :param node_to: The node_to of this QuantumConnection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and node_to is None:  # noqa: E501
            raise ValueError("Invalid value for `node_to`, must not be `None`")  # noqa: E501

        self._node_to = node_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuantumConnection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QuantumConnection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class Output(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entangled_at_time': 'float',
        'entangled_memory_entangled_at_time': 'float',
        'entangled_memory_index': 'float',
        'entangled_with_node': 'str',
        'fidelity': 'float'
    }

    attribute_map = {
        'entangled_at_time': 'entangledAtTime',
        'entangled_memory_entangled_at_time': 'entangledMemoryEntangledAtTime',
        'entangled_memory_index': 'entangledMemoryIndex',
        'entangled_with_node': 'entangledWithNode',
        'fidelity': 'fidelity'
    }

    def __init__(self, entangled_at_time=None, entangled_memory_entangled_at_time=None, entangled_memory_index=None, entangled_with_node=None, fidelity=None, local_vars_configuration=None):  # noqa: E501
        """Output - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._entangled_at_time = None
        self._entangled_memory_entangled_at_time = None
        self._entangled_memory_index = None
        self._entangled_with_node = None
        self._fidelity = None
        self.discriminator = None

        if entangled_at_time is not None:
            self.entangled_at_time = entangled_at_time
        if entangled_memory_entangled_at_time is not None:
            self.entangled_memory_entangled_at_time = entangled_memory_entangled_at_time
        if entangled_memory_index is not None:
            self.entangled_memory_index = entangled_memory_index
        if entangled_with_node is not None:
            self.entangled_with_node = entangled_with_node
        self.fidelity = fidelity

    @property
    def entangled_at_time(self):
        """Gets the entangled_at_time of this Output.  # noqa: E501

        Time at which it was entangled at, relative to beginning of timeline  # noqa: E501

        :return: The entangled_at_time of this Output.  # noqa: E501
        :rtype: float
        """
        return self._entangled_at_time

    @entangled_at_time.setter
    def entangled_at_time(self, entangled_at_time):
        """Sets the entangled_at_time of this Output.

        Time at which it was entangled at, relative to beginning of timeline  # noqa: E501

        :param entangled_at_time: The entangled_at_time of this Output.  # noqa: E501
        :type: float
        """

        self._entangled_at_time = entangled_at_time

    @property
    def entangled_memory_entangled_at_time(self):
        """Gets the entangled_memory_entangled_at_time of this Output.  # noqa: E501

        Time at which it was this memory's entangled memory was entangled at, relative to beginning of timeline  # noqa: E501

        :return: The entangled_memory_entangled_at_time of this Output.  # noqa: E501
        :rtype: float
        """
        return self._entangled_memory_entangled_at_time

    @entangled_memory_entangled_at_time.setter
    def entangled_memory_entangled_at_time(self, entangled_memory_entangled_at_time):
        """Sets the entangled_memory_entangled_at_time of this Output.

        Time at which it was this memory's entangled memory was entangled at, relative to beginning of timeline  # noqa: E501

        :param entangled_memory_entangled_at_time: The entangled_memory_entangled_at_time of this Output.  # noqa: E501
        :type: float
        """

        self._entangled_memory_entangled_at_time = entangled_memory_entangled_at_time

    @property
    def entangled_memory_index(self):
        """Gets the entangled_memory_index of this Output.  # noqa: E501

        The index of the memory this memory is entangled with in entangledWithNode  # noqa: E501

        :return: The entangled_memory_index of this Output.  # noqa: E501
        :rtype: float
        """
        return self._entangled_memory_index

    @entangled_memory_index.setter
    def entangled_memory_index(self, entangled_memory_index):
        """Sets the entangled_memory_index of this Output.

        The index of the memory this memory is entangled with in entangledWithNode  # noqa: E501

        :param entangled_memory_index: The entangled_memory_index of this Output.  # noqa: E501
        :type: float
        """

        self._entangled_memory_index = entangled_memory_index

    @property
    def entangled_with_node(self):
        """Gets the entangled_with_node of this Output.  # noqa: E501

        The node name with which this memory is entangled  # noqa: E501

        :return: The entangled_with_node of this Output.  # noqa: E501
        :rtype: str
        """
        return self._entangled_with_node

    @entangled_with_node.setter
    def entangled_with_node(self, entangled_with_node):
        """Sets the entangled_with_node of this Output.

        The node name with which this memory is entangled  # noqa: E501

        :param entangled_with_node: The entangled_with_node of this Output.  # noqa: E501
        :type: str
        """

        self._entangled_with_node = entangled_with_node

    @property
    def fidelity(self):
        """Gets the fidelity of this Output.  # noqa: E501

        The fidelity of the memory at the current moment in simulation  # noqa: E501

        :return: The fidelity of this Output.  # noqa: E501
        :rtype: float
        """
        return self._fidelity

    @fidelity.setter
    def fidelity(self, fidelity):
        """Sets the fidelity of this Output.

        The fidelity of the memory at the current moment in simulation  # noqa: E501

        :param fidelity: The fidelity of this Output.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and fidelity is None:  # noqa: E501
            raise ValueError("Invalid value for `fidelity`, must not be `None`")  # noqa: E501

        self._fidelity = fidelity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Output):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Output):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.output import Output  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestOutput(unittest.TestCase):
    """Output unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Output
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.output.Output()  # noqa: E501
        if include_optional :
            return Output(
                entangled_at_time = 1.337, 
                entangled_memory_entangled_at_time = 1.337, 
                entangled_memory_index = 1.337, 
                entangled_with_node = '0', 
                fidelity = 1.337
            )
        else :
            return Output(
                fidelity = 1.337,
        )

    def testOutput(self):
        """Test Output"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class MemoryBase(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'coherence_time': 'float',
        'raw_fidelity': 'float'
    }

    attribute_map = {
        'coherence_time': 'coherenceTime',
        'raw_fidelity': 'rawFidelity'
    }

    def __init__(self, coherence_time=-1, raw_fidelity=1, local_vars_configuration=None):  # noqa: E501
        """MemoryBase - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._coherence_time = None
        self._raw_fidelity = None
        self.discriminator = None

        if coherence_time is not None:
            self.coherence_time = coherence_time
        if raw_fidelity is not None:
            self.raw_fidelity = raw_fidelity

    @property
    def coherence_time(self):
        """Gets the coherence_time of this MemoryBase.  # noqa: E501

        The coherence time of the memory, in seconds. (-1 signals infinite coherence time)  # noqa: E501

        :return: The coherence_time of this MemoryBase.  # noqa: E501
        :rtype: float
        """
        return self._coherence_time

    @coherence_time.setter
    def coherence_time(self, coherence_time):
        """Sets the coherence_time of this MemoryBase.

        The coherence time of the memory, in seconds. (-1 signals infinite coherence time)  # noqa: E501

        :param coherence_time: The coherence_time of this MemoryBase.  # noqa: E501
        :type: float
        """

        self._coherence_time = coherence_time

    @property
    def raw_fidelity(self):
        """Gets the raw_fidelity of this MemoryBase.  # noqa: E501

        Fidelity of entanglement in memory  # noqa: E501

        :return: The raw_fidelity of this MemoryBase.  # noqa: E501
        :rtype: float
        """
        return self._raw_fidelity

    @raw_fidelity.setter
    def raw_fidelity(self, raw_fidelity):
        """Sets the raw_fidelity of this MemoryBase.

        Fidelity of entanglement in memory  # noqa: E501

        :param raw_fidelity: The raw_fidelity of this MemoryBase.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                raw_fidelity is not None and raw_fidelity > 1):  # noqa: E501
            raise ValueError("Invalid value for `raw_fidelity`, must be a value less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                raw_fidelity is not None and raw_fidelity < 0):  # noqa: E501
            raise ValueError("Invalid value for `raw_fidelity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._raw_fidelity = raw_fidelity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MemoryBase):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MemoryBase):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class Node(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'measurement_error_probability': 'float',
        'memories': 'list[MemoryInput]',
        'name': 'str',
        'operation_errors': 'dict(str, NodeOperationErrors)'
    }

    attribute_map = {
        'measurement_error_probability': 'measurementErrorProbability',
        'memories': 'memories',
        'name': 'name',
        'operation_errors': 'operationErrors'
    }

    def __init__(self, measurement_error_probability=0, memories=None, name=None, operation_errors=None, local_vars_configuration=None):  # noqa: E501
        """Node - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._measurement_error_probability = None
        self._memories = None
        self._name = None
        self._operation_errors = None
        self.discriminator = None

        if measurement_error_probability is not None:
            self.measurement_error_probability = measurement_error_probability
        self.memories = memories
        self.name = name
        if operation_errors is not None:
            self.operation_errors = operation_errors

    @property
    def measurement_error_probability(self):
        """Gets the measurement_error_probability of this Node.  # noqa: E501


        :return: The measurement_error_probability of this Node.  # noqa: E501
        :rtype: float
        """
        return self._measurement_error_probability

    @measurement_error_probability.setter
    def measurement_error_probability(self, measurement_error_probability):
        """Sets the measurement_error_probability of this Node.


        :param measurement_error_probability: The measurement_error_probability of this Node.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                measurement_error_probability is not None and measurement_error_probability > 1):  # noqa: E501
            raise ValueError("Invalid value for `measurement_error_probability`, must be a value less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                measurement_error_probability is not None and measurement_error_probability < 0):  # noqa: E501
            raise ValueError("Invalid value for `measurement_error_probability`, must be a value greater than or equal to `0`")  # noqa: E501

        self._measurement_error_probability = measurement_error_probability

    @property
    def memories(self):
        """Gets the memories of this Node.  # noqa: E501


        :return: The memories of this Node.  # noqa: E501
        :rtype: list[MemoryInput]
        """
        return self._memories

    @memories.setter
    def memories(self, memories):
        """Sets the memories of this Node.


        :param memories: The memories of this Node.  # noqa: E501
        :type: list[MemoryInput]
        """
        if self.local_vars_configuration.client_side_validation and memories is None:  # noqa: E501
            raise ValueError("Invalid value for `memories`, must not be `None`")  # noqa: E501

        self._memories = memories

    @property
    def name(self):
        """Gets the name of this Node.  # noqa: E501


        :return: The name of this Node.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Node.


        :param name: The name of this Node.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def operation_errors(self):
        """Gets the operation_errors of this Node.  # noqa: E501

        Keys are gate names  # noqa: E501

        :return: The operation_errors of this Node.  # noqa: E501
        :rtype: dict(str, NodeOperationErrors)
        """
        return self._operation_errors

    @operation_errors.setter
    def operation_errors(self, operation_errors):
        """Sets the operation_errors of this Node.

        Keys are gate names  # noqa: E501

        :param operation_errors: The operation_errors of this Node.  # noqa: E501
        :type: dict(str, NodeOperationErrors)
        """

        self._operation_errors = operation_errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Node):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Node):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class SubmissionAqnBaseGlobalSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'excitation_rate': 'float',
        'purification_protocol_name': 'str'
    }

    attribute_map = {
        'excitation_rate': 'excitationRate',
        'purification_protocol_name': 'purificationProtocolName'
    }

    def __init__(self, excitation_rate=80000000, purification_protocol_name='BBPSSW_X', local_vars_configuration=None):  # noqa: E501
        """SubmissionAqnBaseGlobalSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._excitation_rate = None
        self._purification_protocol_name = None
        self.discriminator = None

        if excitation_rate is not None:
            self.excitation_rate = excitation_rate
        if purification_protocol_name is not None:
            self.purification_protocol_name = purification_protocol_name

    @property
    def excitation_rate(self):
        """Gets the excitation_rate of this SubmissionAqnBaseGlobalSettings.  # noqa: E501

        Maximum frequency of excitation for quantum memories (Hz)  # noqa: E501

        :return: The excitation_rate of this SubmissionAqnBaseGlobalSettings.  # noqa: E501
        :rtype: float
        """
        return self._excitation_rate

    @excitation_rate.setter
    def excitation_rate(self, excitation_rate):
        """Sets the excitation_rate of this SubmissionAqnBaseGlobalSettings.

        Maximum frequency of excitation for quantum memories (Hz)  # noqa: E501

        :param excitation_rate: The excitation_rate of this SubmissionAqnBaseGlobalSettings.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                excitation_rate is not None and excitation_rate < 0):  # noqa: E501
            raise ValueError("Invalid value for `excitation_rate`, must be a value greater than or equal to `0`")  # noqa: E501

        self._excitation_rate = excitation_rate

    @property
    def purification_protocol_name(self):
        """Gets the purification_protocol_name of this SubmissionAqnBaseGlobalSettings.  # noqa: E501

        - BBPSSW_X - BBPSSW correcting for bit flips. - BBPSSW_Z - BBPSSW correcting for phase flips. - DSDP - DSSP_X - DSSP correcting for bit flips. - DSSP_Z - DSSP correcting for phase flips. - SSDP   # noqa: E501

        :return: The purification_protocol_name of this SubmissionAqnBaseGlobalSettings.  # noqa: E501
        :rtype: str
        """
        return self._purification_protocol_name

    @purification_protocol_name.setter
    def purification_protocol_name(self, purification_protocol_name):
        """Sets the purification_protocol_name of this SubmissionAqnBaseGlobalSettings.

        - BBPSSW_X - BBPSSW correcting for bit flips. - BBPSSW_Z - BBPSSW correcting for phase flips. - DSDP - DSSP_X - DSSP correcting for bit flips. - DSSP_Z - DSSP correcting for phase flips. - SSDP   # noqa: E501

        :param purification_protocol_name: The purification_protocol_name of this SubmissionAqnBaseGlobalSettings.  # noqa: E501
        :type: str
        """
        allowed_values = ["BBPSSW_X", "BBPSSW_Z", "SSDP", "DSSP_X", "DSSP_Z", "DSDP"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and purification_protocol_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `purification_protocol_name` ({0}), must be one of {1}"  # noqa: E501
                .format(purification_protocol_name, allowed_values)
            )

        self._purification_protocol_name = purification_protocol_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubmissionAqnBaseGlobalSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubmissionAqnBaseGlobalSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.submission_aqn_input import SubmissionAqnInput  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestSubmissionAqnInput(unittest.TestCase):
    """SubmissionAqnInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SubmissionAqnInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.submission_aqn_input.SubmissionAqnInput()  # noqa: E501
        if include_optional :
            return SubmissionAqnInput(
                classical_channels = [
                    aliro_quantum_networking.models.classical_channel.ClassicalChannel(
                        delay = 0, 
                        distance = 0, 
                        node_from = '0', 
                        node_to = '0', )
                    ], 
                global_settings = aliro_quantum_networking.models.submission_aqn_base_global_settings.SubmissionAqnBase_globalSettings(
                    excitation_rate = 0, 
                    purification_protocol_name = 'BBPSSW_X', ), 
                nodes = [
                    aliro_quantum_networking.models.node.Node(
                        measurement_error_probability = 0, 
                        memories = [
                            null
                            ], 
                        name = '0', 
                        operation_errors = {
                            'key' : aliro_quantum_networking.models.node_operation_errors.Node_operationErrors(
                                error_models = [
                                    aliro_quantum_networking.models.error_model.ErrorModel(
                                        error_model_name = 'bitflip', 
                                        probability = 0, )
                                    ], 
                                gate_name = 'CNOT', )
                            }, )
                    ], 
                quantum_connections = [
                    aliro_quantum_networking.models.quantum_connection.QuantumConnection(
                        attenuation = 0, 
                        dark_count_rate = 0, 
                        distance = 0, 
                        efficiency = 0, 
                        error_models = [
                            aliro_quantum_networking.models.error_model.ErrorModel(
                                error_model_name = 'bitflip', 
                                probability = 0, )
                            ], 
                        name = '0', 
                        node_from = '0', 
                        node_to = '0', )
                    ], 
                request = aliro_quantum_networking.models.request.Request(
                    memory_size = 56, 
                    node_from = '0', 
                    node_to = '0', 
                    target_fidelity = 0, 
                    time_beginning = 0, 
                    time_end = 1.337, ), 
                submission_overview = null
            )
        else :
            return SubmissionAqnInput(
                nodes = [
                    aliro_quantum_networking.models.node.Node(
                        measurement_error_probability = 0, 
                        memories = [
                            null
                            ], 
                        name = '0', 
                        operation_errors = {
                            'key' : aliro_quantum_networking.models.node_operation_errors.Node_operationErrors(
                                error_models = [
                                    aliro_quantum_networking.models.error_model.ErrorModel(
                                        error_model_name = 'bitflip', 
                                        probability = 0, )
                                    ], 
                                gate_name = 'CNOT', )
                            }, )
                    ],
                quantum_connections = [
                    aliro_quantum_networking.models.quantum_connection.QuantumConnection(
                        attenuation = 0, 
                        dark_count_rate = 0, 
                        distance = 0, 
                        efficiency = 0, 
                        error_models = [
                            aliro_quantum_networking.models.error_model.ErrorModel(
                                error_model_name = 'bitflip', 
                                probability = 0, )
                            ], 
                        name = '0', 
                        node_from = '0', 
                        node_to = '0', )
                    ],
                request = aliro_quantum_networking.models.request.Request(
                    memory_size = 56, 
                    node_from = '0', 
                    node_to = '0', 
                    target_fidelity = 0, 
                    time_beginning = 0, 
                    time_end = 1.337, ),
                submission_overview = null,
        )

    def testSubmissionAqnInput(self):
        """Test SubmissionAqnInput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum_networking
from aliro_quantum_networking.api.submissions_api import SubmissionsApi  # noqa: E501
from aliro_quantum_networking.rest import ApiException


class TestSubmissionsApi(unittest.TestCase):
    """SubmissionsApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum_networking.api.submissions_api.SubmissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_submissions_delete(self):
        """Test case for submissions_delete

        delete submissions  # noqa: E501
        """
        pass

    def test_submissions_details_stream_get(self):
        """Test case for submissions_details_stream_get

        get details about a submission's results  # noqa: E501
        """
        pass

    def test_submissions_overview_stream_get(self):
        """Test case for submissions_overview_stream_get

        get a list of user's submissions  # noqa: E501
        """
        pass

    def test_submissions_post(self):
        """Test case for submissions_post

        submit a new submission  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.submission_aqn_output_all_of import SubmissionAqnOutputAllOf  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestSubmissionAqnOutputAllOf(unittest.TestCase):
    """SubmissionAqnOutputAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SubmissionAqnOutputAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.submission_aqn_output_all_of.SubmissionAqnOutputAllOf()  # noqa: E501
        if include_optional :
            return SubmissionAqnOutputAllOf(
                run_results = [
                    aliro_quantum_networking.models.submission_aqn_output_all_of_run_results.SubmissionAqnOutput_allOf_runResults(
                        nodes = {
                            'key' : aliro_quantum_networking.models.submission_aqn_output_all_of_nodes.SubmissionAqnOutput_allOf_nodes(
                                memories = [
                                    null
                                    ], )
                            }, 
                        status = aliro_quantum_networking.models.status.Status(
                            status_title = 'COMPLETED', 
                            status_message = '0', ), )
                    ], 
                submission_overview = null
            )
        else :
            return SubmissionAqnOutputAllOf(
                run_results = [
                    aliro_quantum_networking.models.submission_aqn_output_all_of_run_results.SubmissionAqnOutput_allOf_runResults(
                        nodes = {
                            'key' : aliro_quantum_networking.models.submission_aqn_output_all_of_nodes.SubmissionAqnOutput_allOf_nodes(
                                memories = [
                                    null
                                    ], )
                            }, 
                        status = aliro_quantum_networking.models.status.Status(
                            status_title = 'COMPLETED', 
                            status_message = '0', ), )
                    ],
                submission_overview = null,
        )

    def testSubmissionAqnOutputAllOf(self):
        """Test SubmissionAqnOutputAllOf"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class ClassicalChannel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'delay': 'float',
        'distance': 'float',
        'node_from': 'str',
        'node_to': 'str'
    }

    attribute_map = {
        'delay': 'delay',
        'distance': 'distance',
        'node_from': 'nodeFrom',
        'node_to': 'nodeTo'
    }

    def __init__(self, delay=0, distance=1000, node_from=None, node_to=None, local_vars_configuration=None):  # noqa: E501
        """ClassicalChannel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._delay = None
        self._distance = None
        self._node_from = None
        self._node_to = None
        self.discriminator = None

        if delay is not None:
            self.delay = delay
        if distance is not None:
            self.distance = distance
        self.node_from = node_from
        self.node_to = node_to

    @property
    def delay(self):
        """Gets the delay of this ClassicalChannel.  # noqa: E501

        The delay in addition to the travel time in ps (default 500 * 10^6 ps)  # noqa: E501

        :return: The delay of this ClassicalChannel.  # noqa: E501
        :rtype: float
        """
        return self._delay

    @delay.setter
    def delay(self, delay):
        """Sets the delay of this ClassicalChannel.

        The delay in addition to the travel time in ps (default 500 * 10^6 ps)  # noqa: E501

        :param delay: The delay of this ClassicalChannel.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                delay is not None and delay < 0):  # noqa: E501
            raise ValueError("Invalid value for `delay`, must be a value greater than or equal to `0`")  # noqa: E501

        self._delay = delay

    @property
    def distance(self):
        """Gets the distance of this ClassicalChannel.  # noqa: E501

        The distance in meters (default 1000 m)  # noqa: E501

        :return: The distance of this ClassicalChannel.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this ClassicalChannel.

        The distance in meters (default 1000 m)  # noqa: E501

        :param distance: The distance of this ClassicalChannel.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                distance is not None and distance < 0):  # noqa: E501
            raise ValueError("Invalid value for `distance`, must be a value greater than or equal to `0`")  # noqa: E501

        self._distance = distance

    @property
    def node_from(self):
        """Gets the node_from of this ClassicalChannel.  # noqa: E501


        :return: The node_from of this ClassicalChannel.  # noqa: E501
        :rtype: str
        """
        return self._node_from

    @node_from.setter
    def node_from(self, node_from):
        """Sets the node_from of this ClassicalChannel.


        :param node_from: The node_from of this ClassicalChannel.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and node_from is None:  # noqa: E501
            raise ValueError("Invalid value for `node_from`, must not be `None`")  # noqa: E501

        self._node_from = node_from

    @property
    def node_to(self):
        """Gets the node_to of this ClassicalChannel.  # noqa: E501


        :return: The node_to of this ClassicalChannel.  # noqa: E501
        :rtype: str
        """
        return self._node_to

    @node_to.setter
    def node_to(self, node_to):
        """Sets the node_to of this ClassicalChannel.


        :param node_to: The node_to of this ClassicalChannel.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and node_to is None:  # noqa: E501
            raise ValueError("Invalid value for `node_to`, must not be `None`")  # noqa: E501

        self._node_to = node_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassicalChannel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClassicalChannel):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.submission_overview_output import SubmissionOverviewOutput  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestSubmissionOverviewOutput(unittest.TestCase):
    """SubmissionOverviewOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SubmissionOverviewOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.submission_overview_output.SubmissionOverviewOutput()  # noqa: E501
        if include_optional :
            return SubmissionOverviewOutput(
                name = '0', 
                runs = 1, 
                timeout = 1, 
                timeline_stop_time = 0, 
                complete_date = '0', 
                create_date = '0', 
                id = '0', 
                status = 'COMPLETED', 
                submission_overview_type = '0', 
                summary = aliro_quantum_networking.models.statistics_summary.StatisticsSummary(
                    average_entanglement_fidelity = 1.337, 
                    average_entanglement_rate = 1.337, 
                    average_pairs_entangled = 1.337, )
            )
        else :
            return SubmissionOverviewOutput(
                name = '0',
                create_date = '0',
                id = '0',
                status = 'COMPLETED',
                submission_overview_type = '0',
                summary = aliro_quantum_networking.models.statistics_summary.StatisticsSummary(
                    average_entanglement_fidelity = 1.337, 
                    average_entanglement_rate = 1.337, 
                    average_pairs_entangled = 1.337, ),
        )

    def testSubmissionOverviewOutput(self):
        """Test SubmissionOverviewOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum_networking
from aliro_quantum_networking.api.utils_api import UtilsApi  # noqa: E501
from aliro_quantum_networking.rest import ApiException


class TestUtilsApi(unittest.TestCase):
    """UtilsApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum_networking.api.utils_api.UtilsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_utils_support_post(self):
        """Test case for utils_support_post

        Send a support email to Aliro staff  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class SubmissionOverviewInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'runs': 'int',
        'timeout': 'int',
        'timeline_stop_time': 'float',
        'submission_overview_type': 'str'
    }

    attribute_map = {
        'name': 'name',
        'runs': 'runs',
        'timeout': 'timeout',
        'timeline_stop_time': 'timelineStopTime',
        'submission_overview_type': 'submissionOverviewType'
    }

    def __init__(self, name=None, runs=1, timeout=10, timeline_stop_time=1000000000000, submission_overview_type=None, local_vars_configuration=None):  # noqa: E501
        """SubmissionOverviewInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._runs = None
        self._timeout = None
        self._timeline_stop_time = None
        self._submission_overview_type = None
        self.discriminator = None

        self.name = name
        if runs is not None:
            self.runs = runs
        if timeout is not None:
            self.timeout = timeout
        if timeline_stop_time is not None:
            self.timeline_stop_time = timeline_stop_time
        self.submission_overview_type = submission_overview_type

    @property
    def name(self):
        """Gets the name of this SubmissionOverviewInput.  # noqa: E501


        :return: The name of this SubmissionOverviewInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubmissionOverviewInput.


        :param name: The name of this SubmissionOverviewInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def runs(self):
        """Gets the runs of this SubmissionOverviewInput.  # noqa: E501

        Number of times simulation will be run  # noqa: E501

        :return: The runs of this SubmissionOverviewInput.  # noqa: E501
        :rtype: int
        """
        return self._runs

    @runs.setter
    def runs(self, runs):
        """Sets the runs of this SubmissionOverviewInput.

        Number of times simulation will be run  # noqa: E501

        :param runs: The runs of this SubmissionOverviewInput.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                runs is not None and runs > 100):  # noqa: E501
            raise ValueError("Invalid value for `runs`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                runs is not None and runs < 1):  # noqa: E501
            raise ValueError("Invalid value for `runs`, must be a value greater than or equal to `1`")  # noqa: E501

        self._runs = runs

    @property
    def timeout(self):
        """Gets the timeout of this SubmissionOverviewInput.  # noqa: E501

        Maximum time simulation will run, in minutes (default is 10)  # noqa: E501

        :return: The timeout of this SubmissionOverviewInput.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this SubmissionOverviewInput.

        Maximum time simulation will run, in minutes (default is 10)  # noqa: E501

        :param timeout: The timeout of this SubmissionOverviewInput.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                timeout is not None and timeout > 360):  # noqa: E501
            raise ValueError("Invalid value for `timeout`, must be a value less than or equal to `360`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                timeout is not None and timeout < 1):  # noqa: E501
            raise ValueError("Invalid value for `timeout`, must be a value greater than or equal to `1`")  # noqa: E501

        self._timeout = timeout

    @property
    def timeline_stop_time(self):
        """Gets the timeline_stop_time of this SubmissionOverviewInput.  # noqa: E501

        The end time of the simulation, in picoseconds  # noqa: E501

        :return: The timeline_stop_time of this SubmissionOverviewInput.  # noqa: E501
        :rtype: float
        """
        return self._timeline_stop_time

    @timeline_stop_time.setter
    def timeline_stop_time(self, timeline_stop_time):
        """Sets the timeline_stop_time of this SubmissionOverviewInput.

        The end time of the simulation, in picoseconds  # noqa: E501

        :param timeline_stop_time: The timeline_stop_time of this SubmissionOverviewInput.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                timeline_stop_time is not None and timeline_stop_time < 0):  # noqa: E501
            raise ValueError("Invalid value for `timeline_stop_time`, must be a value greater than or equal to `0`")  # noqa: E501

        self._timeline_stop_time = timeline_stop_time

    @property
    def submission_overview_type(self):
        """Gets the submission_overview_type of this SubmissionOverviewInput.  # noqa: E501

        Must be \"SubmissionOverviewInput\"  # noqa: E501

        :return: The submission_overview_type of this SubmissionOverviewInput.  # noqa: E501
        :rtype: str
        """
        return self._submission_overview_type

    @submission_overview_type.setter
    def submission_overview_type(self, submission_overview_type):
        """Sets the submission_overview_type of this SubmissionOverviewInput.

        Must be \"SubmissionOverviewInput\"  # noqa: E501

        :param submission_overview_type: The submission_overview_type of this SubmissionOverviewInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and submission_overview_type is None:  # noqa: E501
            raise ValueError("Invalid value for `submission_overview_type`, must not be `None`")  # noqa: E501

        self._submission_overview_type = submission_overview_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubmissionOverviewInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubmissionOverviewInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class Request(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'memory_size': 'int',
        'node_from': 'str',
        'node_to': 'str',
        'target_fidelity': 'float',
        'time_beginning': 'float',
        'time_end': 'float'
    }

    attribute_map = {
        'memory_size': 'memorySize',
        'node_from': 'nodeFrom',
        'node_to': 'nodeTo',
        'target_fidelity': 'targetFidelity',
        'time_beginning': 'timeBeginning',
        'time_end': 'timeEnd'
    }

    def __init__(self, memory_size=None, node_from=None, node_to=None, target_fidelity=0, time_beginning=1000000000000, time_end=100000000000000, local_vars_configuration=None):  # noqa: E501
        """Request - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._memory_size = None
        self._node_from = None
        self._node_to = None
        self._target_fidelity = None
        self._time_beginning = None
        self._time_end = None
        self.discriminator = None

        self.memory_size = memory_size
        self.node_from = node_from
        self.node_to = node_to
        if target_fidelity is not None:
            self.target_fidelity = target_fidelity
        if time_beginning is not None:
            self.time_beginning = time_beginning
        if time_end is not None:
            self.time_end = time_end

    @property
    def memory_size(self):
        """Gets the memory_size of this Request.  # noqa: E501


        :return: The memory_size of this Request.  # noqa: E501
        :rtype: int
        """
        return self._memory_size

    @memory_size.setter
    def memory_size(self, memory_size):
        """Sets the memory_size of this Request.


        :param memory_size: The memory_size of this Request.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and memory_size is None:  # noqa: E501
            raise ValueError("Invalid value for `memory_size`, must not be `None`")  # noqa: E501

        self._memory_size = memory_size

    @property
    def node_from(self):
        """Gets the node_from of this Request.  # noqa: E501

        A string matching the name of the sending node  # noqa: E501

        :return: The node_from of this Request.  # noqa: E501
        :rtype: str
        """
        return self._node_from

    @node_from.setter
    def node_from(self, node_from):
        """Sets the node_from of this Request.

        A string matching the name of the sending node  # noqa: E501

        :param node_from: The node_from of this Request.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and node_from is None:  # noqa: E501
            raise ValueError("Invalid value for `node_from`, must not be `None`")  # noqa: E501

        self._node_from = node_from

    @property
    def node_to(self):
        """Gets the node_to of this Request.  # noqa: E501

        A string matching the name of the receiving node  # noqa: E501

        :return: The node_to of this Request.  # noqa: E501
        :rtype: str
        """
        return self._node_to

    @node_to.setter
    def node_to(self, node_to):
        """Sets the node_to of this Request.

        A string matching the name of the receiving node  # noqa: E501

        :param node_to: The node_to of this Request.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and node_to is None:  # noqa: E501
            raise ValueError("Invalid value for `node_to`, must not be `None`")  # noqa: E501

        self._node_to = node_to

    @property
    def target_fidelity(self):
        """Gets the target_fidelity of this Request.  # noqa: E501

        The target fidelity of the network  # noqa: E501

        :return: The target_fidelity of this Request.  # noqa: E501
        :rtype: float
        """
        return self._target_fidelity

    @target_fidelity.setter
    def target_fidelity(self, target_fidelity):
        """Sets the target_fidelity of this Request.

        The target fidelity of the network  # noqa: E501

        :param target_fidelity: The target_fidelity of this Request.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                target_fidelity is not None and target_fidelity > 1):  # noqa: E501
            raise ValueError("Invalid value for `target_fidelity`, must be a value less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                target_fidelity is not None and target_fidelity < 0):  # noqa: E501
            raise ValueError("Invalid value for `target_fidelity`, must be a value greater than or equal to `0`")  # noqa: E501

        self._target_fidelity = target_fidelity

    @property
    def time_beginning(self):
        """Gets the time_beginning of this Request.  # noqa: E501

        Start time for the simulation, in picoseconds (default is 10^12)  # noqa: E501

        :return: The time_beginning of this Request.  # noqa: E501
        :rtype: float
        """
        return self._time_beginning

    @time_beginning.setter
    def time_beginning(self, time_beginning):
        """Sets the time_beginning of this Request.

        Start time for the simulation, in picoseconds (default is 10^12)  # noqa: E501

        :param time_beginning: The time_beginning of this Request.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                time_beginning is not None and time_beginning < 0):  # noqa: E501
            raise ValueError("Invalid value for `time_beginning`, must be a value greater than or equal to `0`")  # noqa: E501

        self._time_beginning = time_beginning

    @property
    def time_end(self):
        """Gets the time_end of this Request.  # noqa: E501

        End time for the simulation, in picoseconds (default is 10^14)  # noqa: E501

        :return: The time_end of this Request.  # noqa: E501
        :rtype: float
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """Sets the time_end of this Request.

        End time for the simulation, in picoseconds (default is 10^14)  # noqa: E501

        :param time_end: The time_end of this Request.  # noqa: E501
        :type: float
        """

        self._time_end = time_end

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Request):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Request):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum_networking.configuration import Configuration


class SubmissionAqnBase(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'classical_channels': 'list[ClassicalChannel]',
        'global_settings': 'SubmissionAqnBaseGlobalSettings',
        'nodes': 'list[Node]',
        'quantum_connections': 'list[QuantumConnection]',
        'request': 'Request'
    }

    attribute_map = {
        'classical_channels': 'classicalChannels',
        'global_settings': 'globalSettings',
        'nodes': 'nodes',
        'quantum_connections': 'quantumConnections',
        'request': 'request'
    }

    def __init__(self, classical_channels=None, global_settings=None, nodes=None, quantum_connections=None, request=None, local_vars_configuration=None):  # noqa: E501
        """SubmissionAqnBase - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._classical_channels = None
        self._global_settings = None
        self._nodes = None
        self._quantum_connections = None
        self._request = None
        self.discriminator = None

        if classical_channels is not None:
            self.classical_channels = classical_channels
        if global_settings is not None:
            self.global_settings = global_settings
        self.nodes = nodes
        self.quantum_connections = quantum_connections
        self.request = request

    @property
    def classical_channels(self):
        """Gets the classical_channels of this SubmissionAqnBase.  # noqa: E501


        :return: The classical_channels of this SubmissionAqnBase.  # noqa: E501
        :rtype: list[ClassicalChannel]
        """
        return self._classical_channels

    @classical_channels.setter
    def classical_channels(self, classical_channels):
        """Sets the classical_channels of this SubmissionAqnBase.


        :param classical_channels: The classical_channels of this SubmissionAqnBase.  # noqa: E501
        :type: list[ClassicalChannel]
        """

        self._classical_channels = classical_channels

    @property
    def global_settings(self):
        """Gets the global_settings of this SubmissionAqnBase.  # noqa: E501


        :return: The global_settings of this SubmissionAqnBase.  # noqa: E501
        :rtype: SubmissionAqnBaseGlobalSettings
        """
        return self._global_settings

    @global_settings.setter
    def global_settings(self, global_settings):
        """Sets the global_settings of this SubmissionAqnBase.


        :param global_settings: The global_settings of this SubmissionAqnBase.  # noqa: E501
        :type: SubmissionAqnBaseGlobalSettings
        """

        self._global_settings = global_settings

    @property
    def nodes(self):
        """Gets the nodes of this SubmissionAqnBase.  # noqa: E501


        :return: The nodes of this SubmissionAqnBase.  # noqa: E501
        :rtype: list[Node]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """Sets the nodes of this SubmissionAqnBase.


        :param nodes: The nodes of this SubmissionAqnBase.  # noqa: E501
        :type: list[Node]
        """
        if self.local_vars_configuration.client_side_validation and nodes is None:  # noqa: E501
            raise ValueError("Invalid value for `nodes`, must not be `None`")  # noqa: E501

        self._nodes = nodes

    @property
    def quantum_connections(self):
        """Gets the quantum_connections of this SubmissionAqnBase.  # noqa: E501


        :return: The quantum_connections of this SubmissionAqnBase.  # noqa: E501
        :rtype: list[QuantumConnection]
        """
        return self._quantum_connections

    @quantum_connections.setter
    def quantum_connections(self, quantum_connections):
        """Sets the quantum_connections of this SubmissionAqnBase.


        :param quantum_connections: The quantum_connections of this SubmissionAqnBase.  # noqa: E501
        :type: list[QuantumConnection]
        """
        if self.local_vars_configuration.client_side_validation and quantum_connections is None:  # noqa: E501
            raise ValueError("Invalid value for `quantum_connections`, must not be `None`")  # noqa: E501

        self._quantum_connections = quantum_connections

    @property
    def request(self):
        """Gets the request of this SubmissionAqnBase.  # noqa: E501


        :return: The request of this SubmissionAqnBase.  # noqa: E501
        :rtype: Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this SubmissionAqnBase.


        :param request: The request of this SubmissionAqnBase.  # noqa: E501
        :type: Request
        """
        if self.local_vars_configuration.client_side_validation and request is None:  # noqa: E501
            raise ValueError("Invalid value for `request`, must not be `None`")  # noqa: E501

        self._request = request

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubmissionAqnBase):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubmissionAqnBase):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum_networking
from aliro_quantum_networking.models.email_info import EmailInfo  # noqa: E501
from aliro_quantum_networking.rest import ApiException

class TestEmailInfo(unittest.TestCase):
    """EmailInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EmailInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum_networking.models.email_info.EmailInfo()  # noqa: E501
        if include_optional :
            return EmailInfo(
                content_text = '0', 
                subject = '0'
            )
        else :
            return EmailInfo(
        )

    def testEmailInfo(self):
        """Test EmailInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Aliro Q.Network

    This is an api for the Aliro Q.Network  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from aliro_quantum_networking.api.authentication_api import AuthenticationApi
from aliro_quantum_networking.api.submissions_api import SubmissionsApi
from aliro_quantum_networking.api.user_api import UserApi
from aliro_quantum_networking.api.utils_api import UtilsApi

# import ApiClient
from aliro_quantum_networking.api_client import ApiClient
from aliro_quantum_networking.configuration import Configuration
from aliro_quantum_networking.exceptions import OpenApiException
from aliro_quantum_networking.exceptions import ApiTypeError
from aliro_quantum_networking.exceptions import ApiValueError
from aliro_quantum_networking.exceptions import ApiKeyError
from aliro_quantum_networking.exceptions import ApiException
# import models into sdk package
from aliro_quantum_networking.models.api_key import ApiKey
from aliro_quantum_networking.models.api_key_response import ApiKeyResponse
from aliro_quantum_networking.models.basic_success import BasicSuccess
from aliro_quantum_networking.models.change_password_parameters import ChangePasswordParameters
from aliro_quantum_networking.models.classical_channel import ClassicalChannel
from aliro_quantum_networking.models.credentials_basic import CredentialsBasic
from aliro_quantum_networking.models.email_info import EmailInfo
from aliro_quantum_networking.models.error_model import ErrorModel
from aliro_quantum_networking.models.login_response import LoginResponse
from aliro_quantum_networking.models.memory_base import MemoryBase
from aliro_quantum_networking.models.memory_input import MemoryInput
from aliro_quantum_networking.models.memory_output import MemoryOutput
from aliro_quantum_networking.models.node import Node
from aliro_quantum_networking.models.node_operation_errors import NodeOperationErrors
from aliro_quantum_networking.models.output import Output
from aliro_quantum_networking.models.quantum_connection import QuantumConnection
from aliro_quantum_networking.models.register_params import RegisterParams
from aliro_quantum_networking.models.register_params_all_of import RegisterParamsAllOf
from aliro_quantum_networking.models.request import Request
from aliro_quantum_networking.models.statistics_summary import StatisticsSummary
from aliro_quantum_networking.models.status import Status
from aliro_quantum_networking.models.status_title import StatusTitle
from aliro_quantum_networking.models.string_response import StringResponse
from aliro_quantum_networking.models.submission_aqn_base import SubmissionAqnBase
from aliro_quantum_networking.models.submission_aqn_base_global_settings import SubmissionAqnBaseGlobalSettings
from aliro_quantum_networking.models.submission_aqn_input import SubmissionAqnInput
from aliro_quantum_networking.models.submission_aqn_input_all_of import SubmissionAqnInputAllOf
from aliro_quantum_networking.models.submission_aqn_output import SubmissionAqnOutput
from aliro_quantum_networking.models.submission_aqn_output_all_of import SubmissionAqnOutputAllOf
from aliro_quantum_networking.models.submission_aqn_output_all_of_nodes import SubmissionAqnOutputAllOfNodes
from aliro_quantum_networking.models.submission_aqn_output_all_of_run_results import SubmissionAqnOutputAllOfRunResults
from aliro_quantum_networking.models.submission_id_object import SubmissionIdObject
from aliro_quantum_networking.models.submission_overview_base import SubmissionOverviewBase
from aliro_quantum_networking.models.submission_overview_input import SubmissionOverviewInput
from aliro_quantum_networking.models.submission_overview_input_all_of import SubmissionOverviewInputAllOf
from aliro_quantum_networking.models.submission_overview_output import SubmissionOverviewOutput
from aliro_quantum_networking.models.submission_overview_output_all_of import SubmissionOverviewOutputAllOf
from aliro_quantum_networking.models.submissions_overview_stream_response import SubmissionsOverviewStreamResponse
from aliro_quantum_networking.models.update_user_information_parameters import UpdateUserInformationParameters
from aliro_quantum_networking.models.user_info import UserInfo

